@@ -6,7 +6,7 @@ Rubric::Renderer - the rendering interface for Rubric
 
 =head1 VERSION
 
- $Id: Renderer.pm,v 1.4 2004/12/14 04:30:54 rjbs Exp $
+ $Id: Renderer.pm,v 1.9 2005/03/17 02:55:33 rjbs Exp $
 
 =head1 DESCRIPTION
 
@@ -18,16 +18,21 @@ and other things collected by Rubric::WebApp.
 use strict;
 use warnings;
 
+use Carp;
 use Rubric::Config;
 use Template;
 
 =head1 METHODS
 
-=head2 renderer
+=head2 register_type($type => \%arg)
 
-This method returns an object that renders templates.  By default, it returns a
-Template object configured with data from Rubric::Config.  Each type's renderer
-is a singleton.
+This method registers a format type by providing a little data needed to render
+to it.  The hashref of arguments must include C<content_type>, used to set the
+MIME type of the returned ouput; and C<extension>, used to find the primary
+template.
+
+This method returns a Template object, which is registered as the renderer for
+this type.  This return value may change in the future.
 
 =cut
 
@@ -43,17 +48,45 @@ sub register_type {
 }
 
 __PACKAGE__->register_type(@$_) for (
-	[ html => { content_type => 'text/html',           extension => 'html' } ],
+	[ html => { content_type => 'text/html; charset="utf-8"', extension => 'html' } ],
 	[ rss  => { content_type => 'application/rss+xml', extension => 'rss'  } ],
 	[ txt  => { content_type => 'text/plain',          extension => 'txt'  } ],
+	[ api  => { content_type => 'text/xml',            extension => 'api'  } ],
 );
 
+=head2 process($template, $type, \%stash)
+
+This method renders the named template using the registered renderer for the
+given type, using the passed stash variables.
+
+The type must be rendered with Rubric::Renderer before this method is called.
+
+In list context, this method returns the content type and output document as a
+two-element list.  In scalar context, it returns the output document.
+
+=cut
+
+my $xml_escape = sub {
+	for (shift) {
+		s/&/&amp;/g;
+		s/</&lt;/g;
+		s/>/&gt;/g;
+		s/"/&quot;/g;
+		s/'/&apos;/g;
+		return $_;
+	}
+};
+
 sub process { 
 	my ($class, $template, $type, $stash) = @_;
 	return unless $renderer{$type};
 
+	$stash->{xml_escape} = $xml_escape;
+
 	$template .= '.' . $renderer{$type}{extension};
-	$renderer{$type}{renderer}->process($template, $stash, \(my $output));
+	$renderer{$type}{renderer}->process($template, $stash, \(my $output))
+		or die "Couldn't render template: " . $renderer{$type}{renderer}->error;
+	die "template produced no content" unless $output;
 	return wantarray
 		? ($renderer{$type}{content_type}, $output)
 		:  $output;
